@@ -11,7 +11,7 @@
 #
 #
 "K3p" <-
-function(S=35,T=25,P=0,pHscale="T",kSWS2scale=0){
+function(S=35,T=25,P=0,pHscale="T",kSWS2scale=0,warn="y"){
 
     nK <- max(length(S), length(T), length(P), length(pHscale), length(kSWS2scale))
 
@@ -65,7 +65,7 @@ function(S=35,T=25,P=0,pHscale="T",kSWS2scale=0){
     # ----------------- If needed, Pressure Correction ------------------
             
     if (any (P != 0)) 
-        K3P <- Pcorrect(Kvalue=K3P, Ktype="K3p", T=T, S=S, P=P, pHscale="SWS", 1., 1.)
+        K3P <- Pcorrect(Kvalue=K3P, Ktype="K3p", T=T, S=S, P=P, pHscale="SWS", 1., 1., warn=warn)
 
     ###----------------pH scale corrections
 
@@ -102,7 +102,9 @@ function(S=35,T=25,P=0,pHscale="T",kSWS2scale=0){
 
     ##------------Warnings
 
-    if (any (T>45 | S>45 | T<0) ) {warning("S and/or T is outside the range of validity of the formulation available for K3p in seacarb.")}
+    is_w <- warn == "y"
+
+    if (any (is_w & (T>45 | S>45 | T<0)) ) {warning("S and/or T is outside the range of validity of the formulation available for K3p in seacarb.")}
 
     attr(K3P,"unit")     = "mol/kg-soln"
     attr(K3P,"pH scale") = pHsc
